%
%                       COADS MONTHLY DATASETS

% The preceding empty line is important.
%
% $Id: coadmon.m,v 1.6 1999/03/06 00:06:48 dbyrne Exp $

% $Log: coadmon.m,v $
% Revision 1.6  1999/03/06 00:06:48  dbyrne
%
%
% update for new release.
%
% Revision 1.8  1999/03/04 13:13:25  root
% All changes since AGU week.
%
% Revision 1.5  1998/11/18 19:57:01  dbyrne
%
%
% Second try.  Bug fixes to jpl pathfinder data, changed names of
% Reynolds datasets to clarify that one is a climatology and one is not.
%
% Revision 1.7  1998/11/05 16:01:51  root
% Changed LonVector and LatVector to be used if no Lon returned and tried the update function.
% DataScale and DataNull should now be optional!
%
% Revision 1.2  1998/09/14 01:32:53  dbyrne
% Elminated an inconsistency whereby the depth variable was not scaled
% and had no DataNull etc.  Added check for empty variables to plotscript.m
%
% Revision 1.6  1998/09/13 19:33:22  root
% updated DataNull &c.
%
% Revision 1.5  1998/09/13 19:21:22  root
% Eliminated an inconsistency in DataScale, DataRange, and DataNull, that
% Depth was not included!
%
% Revision 1.4  1998/09/11 08:16:07  dbyrne
% Longitude ranges were messed up in every archive.m file except the
% two I wrote myself.  To eliminate future confusion, 'LLon' 'Llat',
% 'Rlon' and 'Ulat' etc are being eliminated in favor of two-component
% vectors LonRange LatRange TimeRange DepthRange.
%
% Revision 1.3  1998/09/09 20:12:15  dbyrne
% Changing variable names to stay within 14 characters.
%
% Revision 1.2  1998/09/09 07:57:35  dbyrne
% replaced Data_Scale with DataScale, Data_Null with DataNull, and Data_Range
% with DataRange for consistency with other variables in the archive.m files.
%
% Revision 1.1  1998/09/08 21:17:07  dbyrne
% The COADS monthly datasets.
%
% Revision 1.1  1998/05/17 14:17:57  dbyrne
% *** empty log message ***
%
% Revision 1.2  1997/12/09 20:41:14  tom
% changed latitude limits from -89,89 to -90,90
%
% Revision 1.1  1997/10/25 18:01:56  jimg
% Added to GUI
%
% Revision 1.5  1997/10/09 22:05:56  jimg
% Merged changes from 2.14c
%
% Revision 1.4  1997/10/04 00:33:29  jimg
% Release 2.14c fixes
%
% Revision 1.3  1997/10/01 16:34:03  tom
% fixed Nlon and Nlat errors
%
% Revision 1.2  1997/09/30 14:37:48  tom
% fixed erroneous longitude limit
%
% Revision 1.1.1.1  1997/09/22 14:13:54  tom
% Imported Matlab GUI sources to CVS
%

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL
URL_m_File = 'coadurl';
CatalogServer = 'monthly';

% VARIABLES -- OPTIONAL
Server = str2mat('coads_air.nc','coads_cldc.nc','coads_lflx.nc',...
    'coads_rhum.nc','coads_sflx.nc','coads_shum.nc', 'coads_slp.nc', ...
    'coads_sst.nc', 'coads_ustr.nc', str2mat('coads_vstr.nc', ...
    'coads_uwnd.nc', 'coads_vwnd.nc'));
Nlon = 180;
Nlat = 90;

% VARIABLES -- REQUIRED
LonRange = [0.0 360.0];
LatRange = [-90.0 90.0];
TimeRange = [1854 1994];
DepthRange = [0.0 0.0];
Resolution = 219.5;

%DataName = 'COADS Monthly Datasets';
                                          % PCC Changed 12/13/98 to regularize names.
DataName = 'Surface - COADS Monthly Datasets - PMEL';
TimeName = 'TIME';
LongitudeName = 'LON';
LatitudeName = 'LAT';
DepthName = '';
SelectableVariables = str2mat('Air_Temp', 'Cloud_Cover', ...
    'Latent_Heat', 'Rel_Humidity', 'Sensible_Heat', ...
    'Spec_Humidity', 'Pressure', 'Sea_Temp', ...
    'U_Wind_Stress', str2mat('V_Wind_Stress', ...
    'U_Wind', 'V_Wind'));
DodsName = str2mat('AIR','CLDC','LFLX','RHUM','SFLX', ...
    'SHUM', 'SLP', 'SST', 'USTR', ...
    str2mat('VSTR', 'UWND', 'VWND'));

% note: DataNull is applied *before* scaling
DataNull = [NaN NaN NaN NaN -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0 ...
      -9999999790214767953607394487959552.0];
DataScale = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; 0 1; 0 1; 0 1; 0 1; ...
  0 1; 0 1; 0 1; 0 1; 0 1; 0 1; 0 1; 0 1];
DataRange = [NaN NaN; NaN NaN; -90 90; NaN NaN; 6 32; 0 8; -16 122; ...
  50 100; -60 70; 4 25; 970 1040; 0 32.0; -300 300; -300 300; -20 20; ...
  -20 20];

% COMMENTS
Comments1 = sprintf('%s\n', ...
'         COADS (Comprehensive Ocean-Atmosphere Data Set) Data at PMEL', ...
'                    Monthly Datasets', ...
'    ', ...
'    This dataset contains monthly averages based on COADS (Comprehensive ', ...
'    Ocean-Atmosphere Data Set) data. The data are based on observations', ...
'    available during the time period 1854-1992.  Data units are list in the ', ...
'    table below.   Data are in 2x2 degree bins.', ...
'    ', ...
'    Note:  The origin of the data grid (indicies (1,1)) has a lat/long value of ', ...
'    (-90,20), and a corresponding terminal point (indices (90,180)) corresponding ', ...
'    to (90,380).  Longitude values span 360 degrees, from 20-380 degrees.', ...
'    ', ...
'                      General Summary of the COADS Data ', ...
'    ', ...
'    The Comprehensive Ocean-Atmosphere Data Set (COADS)* has been created by ', ...
'    combining, editing, and summarizing global in situ marine data from many ', ...
'    different sources.  Merchant ship observations back to 1854 have been ', ...
'    supplemented in more recent years by automated measurements, e.g., from ', ...
'    drifting and moored buoys.  COADS currently covers the period 1854-1992.  Two ', ...
'    COADS products are most often requested by users (decadal summaries and other ', ...
'    products are also available): ', ...
'         i) Marine reports: These contain the basic individual observations (e.g., ', ...
'         of air and sea surface temperatures, winds, atmospheric pressure, ', ...
'         cloudiness, and humidity) taken from the ocean-atmosphere boundary layer. ', ...
'    ', ...
'         ii) Global monthly summaries for 2-degree latitude x 2-degree longitude ', ...
'         boxes.  Fourteen statistics, such as the median and mean, were calculated ', ...
'         for each of 19 observed and derived variables.  The statistics are global ', ...
'         only to the extent that observations were actually recorded at a given ', ...
'         time and place (i.e., statistics were calculated for each year, month, and ', ...
'         2-degree box containing "acceptable" data).  Due to data volume, ', ...
'         statistics are often requested in the form of group files, each group ', ...
'         containing eight selected statistics for four variables. ', ...
'    ', ...
'    The various COADS datasets available from the NOAA/PMEL Archive reference the ', ...
'    following parameters:');

Comments2 = sprintf('%s\n', ...
'    ', ...
'    "Observed" variables             Name     Units           Precision ', ...
'      Air temperature                      air        deg C           0.01 ', ...  
'      Sea level pressure                 slp        mb                0.01 ', ...
'      Sea surface temperature        sst       deg C           0.01 ', ...
'      u-wind                                   uwnd    m/s               0.01 ', ...
'      v-wind                                   vwnd    m/s               0.01 ', ...
'      Scalar wind                            wspd    m/s               0.01 ', ...
'      Cloudiness                             cldc      okta              0.1 ', ...
'      Specific humidity                    shum    g/kg              0.01 ', ...
'    ', ...
'    Derived variables', ...
'      Relative humidity                    rhum     %                 0.1  ', ...
'      Sensible heat parameter ', ...
'        (sst - air) * wspd                 sflx    degC*m/s        0.1 ', ...
'      Latent heat parameter ((saturation', ...
'        shum at sst) - shum)*wspd   lflx     g/kg               0.01 ', ...
'      u-wind stress (wspd * uwnd)   ustr    m^2/s^2        0.1 ', ...
'      v-wind stress (wspd * vwnd)   vstr    m^2/s^2        0.1 ', ... 
'    ');

Comments3 = sprintf('%s\n', ...
'    Statistic                               Abbreviation', ...
'    ', ...
'      Mean                                       mean', ...
'      Number of Observations           nobs', ...
'      Long Term Mean                      ltm', ...
'    ', ...
'    Spatial coverage: ', ...
'    ', ...
'         90N-90S (by 2.0), 1-359E (by 2.0) ', ...
'         (specified coordinates refer to center of 2-degree boxes) ', ...
'    ', ...
'    Temporal coverage: ', ...
'    ', ...
'         January 1854 through December 1992 ', ...
'         monthly means and monthly numbers of observations ', ...
'    ', ...
'    Levels: ', ...
'    ', ...
'         Surface data.  ', ...         
'    ', ...
'    References: ', ...
'    ', ...
'       Live Access to Climate Data. NOAA/PMEL WWW Server', ...
'          "http://ferret.wrc.noaa.gov/fbin/climate_server"', ...
'    ', ...
'       Diaz, H.F., K. Wolter, and S.D. Woodruff (Eds.), 1992: Proceedings of the ', ...
'          International COADS Workshop, Boulder, Colorado, 13-15 January 1992. ', ...
'          NOAA Environmental Research Laboratories, Climate Research Program, ', ...
'          Boulder, CO, 390 pp.', ...
'    ', ...
'       Elms, J.D., S.D. Woodruff, S.J. Worley, and C. Hanson, 1994: Digitizing ', ...
'          Historical Records for the Comprehensive Ocean-Atmosphere Data Set ', ...
'          (COADS) Earth System Monitor, 4, No. 2, 4-10.', ...
'    ', ...
'       Slutz, R.J., S.J. Lubker, J.D. Hiscox, S.D. Woodruff, R.L. Jenne, D.H. ', ...
'          Joseph, P.M. Steurer, and J.D. Elms, 1985: Comprehensive Ocean-Atmosphere ', ...
'          Data Set; Release 1. NOAA EnvironmentalResearch Laboratories, Climate ', ...
'          Research Program, Boulder, CO, 268 pp.', ...
'    ', ...
'       Woodruff, S.D., S.J. Lubker, K. Wolter, S.J. Worley, and J.D. Elms, 1993: ', ...
'          ComprehensiveOcean-Atmosphere Data Set (COADS) Release 1a: 1980-92. ', ...
'          Earth System Monitor, 4, No. 1 September 1993, 1-8.', ...
'    ', ...
'       Woodruff, S.D., R.J. Slutz, R.L. Jenne, and P.M. Steurer, 1987: A ', ...
'          comprehensive ocean-atmosphere data set. Bull. Amer. Meteor. Soc., 68, ', ...
'          1239-1250.');
Comments4 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date:1946 ', ...
'         Ending_Date:1992 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:0.0 ', ...
'              East Bounding Coordinate:360.0 ', ...
'              South Bounding Coordinate:-90.00 ', ...
'              North Bounding Coordinate:+90.00 ', ...
'   ', ...
'    Point_of_Contact (Science) = ', ...
'         Address: ', ...
'               Scott Woodruff ', ...
'               Climate Diagnostics Center ', ...
'               NOAA/ERL/R/E/CD ', ...
'               325 Broadway ', ...
'               Boulder, Colorado 80303 ', ...
'               USA ', ...
'               Phone: (303) 497-6747', ...
'         Electronic Mail Address:INTERNET > sdw@cdc.noaa.gov ', ...
'    Point_of_Contact (Data Provision) = ', ...
'         Address: ', ...
'               Kevin O''Brien ', ...
'               NOAA/PMEL', ...
'               7600 Sand Point Way NE', ...
'               Seattle, Washington 98115-0070', ...
'               USA ', ...
'               Telephone: (206) 526-6751', ...
'         Electronic Mail Address:INTERNET > ferret@pmel.noaa.gov');

Comments = [Comments1 Comments2 Comments3 Comments4];

