%
% FSU Pacific Monthly Pseudostress Averages

GetFunctionName = 'getrectg';

URL_m_File = 'fsupstressurl';
CatalogServer = 'monthly';

Server = str2mat('pac_pstress.61-97.nc');
Nlon = 84;
Nlat = 30;

LonRange = [123 291];
LatRange = [-30 30];
TimeRange = [1961.0 1998.0];
DepthRange = [0.0 0.0];
Resolution = 222;

%DataName = 'FSU Pacific Monthly Pseudostress Averages Dataset';
                                          % PCC Changed 12/13/98 to regularize names.
DataName = 'Wind - Pacific Monthly Pseudostress Averages - FSU';
TimeName = 'time';
LongitudeName = 'lon';
LatitudeName = 'lat';
DepthName = '';
SelectableVariables = str2mat('U_Wind_Pseudostress', 'V_Wind_Pseudostress');
DodsName = str2mat('Wu', 'Wv');

DataNull = [NaN NaN NaN NaN 9990 9990];
%DataScale = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; 0 1];
DataRange = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; -2000 1550; -1250 1440];

Comments1 = sprintf('%s\n', ...
'                       FSU Pacific Monthly Pseudostress Averages ', ...
'     ', ...
'    These data are monthly averaged observations based on data available during the ',...
'    time period 1961-1998 for that month binned on a global 2x2 degree grid (i.e., the ',...
'    dataset contains 12 grids, one for each month of the year).',...
'    ', ...
'    The data set has been created by screening, binning and subjectively analysing ',...
'    individual observations on 2-deg latitude, 10-deg longitude grid, and is digitized ',...
'    onto 2x2-deg grid. The ananlysis for the years 1961-1965 are based on the Wyrtki-Meyers ',...
'    data set, while the analysis for the years 1966-1980 is based on the COADS data set.',...
'    ', ...
'    References',...
'    ', ...
'    Legler, D.M., and J.J. O''Brien, 1988: Tropical Pacific wind stress analysis for TOGA, ',...
'    IOC Time series of ocean measurements, IOC Technical Series 33, Volume 4, UNESCO. ',...
'    ',...
'    Stricherz, Jame N., J. J. O''Brien, and D. M. Legler, 1992: Atlas of Florida State ',...
'    University Tropical Pacific Winds for TOGA 1966-1985, Florida State University, ',...
'    Tallahassee, FL, 250 pp. ',...
'    ',...
'    Stricherz, James N., David M. Legler, and James J. O''Brien, 1997: TOGA Pseudo-stress Atlas',...
'    1985-1994, Volume II: Pacific Ocean, Florida State University, Tallahassee, FL, 155 pp. ',...
'    ', ...
'    Wyrtki, K. and G. Meyers, 1975: The trade wind field over the Pacific Ocean. Part I. The ',...
'    mean field and mean annual variation. Hawaii Inst. Geophys., University of Hawaii. HIG-',...
'    75-1, 26 pp. ',...
'    ',...
'    Slutz, R. J., S. J. Lubker, J. D. Hiscox, S. D. Woodruff, R. L. Jenne, D. H. Joseph, P. M.',...
'    Seurer and J. D. Elms, COADS-Comprehenisve Ocean-Atmosphere Data Set, CIRES/ERL/NCAR/NCDC, ',...
'    Boulder, CO, 1985. .');

Comments2 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: Jan. 1, 1961 ', ...
'         Ending_Date: Dec. 31, 1997 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:   70 W ', ...
'              East Bounding Coordinate:  124 E ', ...
'              South Bounding Coordinate:  29 S ', ...
'              North Bounding Coordinate:  29 N ', ...
'    Units:  m2/s2 ', ...
'    Spatial Resolution: 220 km', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address: ', ...
'         Electronic Mail Address: INTERNET > INTERNET > support@dods.gso.uri.edu ');

Comments = [Comments1 Comments2];



