%
%               FILE DESCRIBING THE URI HIGH RESOLUTION SST DATA SET
%                              Florida to Cape Hatteras
%

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL
Cat_m_File = 'urieccat';
URL_m_File = 'fthurl';

% VARIABLES -- OPTIONAL
Server = 'http://fronts.gso.uri.edu/cgi-bin/nph-dsp/fth_sst_decloud/';
CatalogServer = 'http://dods.gso.uri.edu/cgi-bin/nph-jg/fth_sst_decloud';
Nlon = 1024;
Nlat = 1024;

% VARIABLES -- REQUIRED
LonRange = [-82.962 -68.497];
LatRange = [35.356 24.308];
TimeRange = [1985 1990];
DepthRange = [0 0];
Resolution = 1.236;                  % avg res.

%DataName = 'Florida to Hatteras AVHRR'; % Name for this dataset.
                                          % PCC Changed 12/13/98 to regularize names.
DataName = 'SST - Florida to Hatteras AVHRR - URI'; % Name for this dataset.
TimeName = '';
LongitudeName = 'lon';
LatitudeName = 'lat';
DepthName = '';
SelectableVariables = str2mat('Sea_Temp');
DodsName = 'dsp_band_1';

% note: DataNull is applied *before* scaling
DataNull = [NaN NaN NaN NaN 0];
DataScale = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; 2.0  0.125];
DataRange = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; 2.65 33.875];

% COMMENTS
Comments1 = sprintf('%s\n', ...
'                  URI 1.1km Florida to Hatteras SST fields', ...
'     ', ...
'    This is a subset of the University of Rhode Island, Graduate School of ', ...
'    Oceanography''s archive of sea surface temperature satellite images. These', ...
'    images are processed Advanced Very High Resolution Radiometer (AVHRR)', ...
'    data from NOAA satellites. ', ...
'    ', ...
'    The archive contains up to 5 images per day. We are reprocessing all', ...
'    of the data in our archive which covers the period from April 1979 to', ...
'    the present.  We began the reprocessing effort with data in the late', ...
'    1980''s and are processing forward and backward in time. The NASA/NOAA', ...
'    Pathfinder SST algorithm is being used for the reprocessing. Each of the ', ...
'    1024 by 1024 pixel images in the archive covers the area from latitude 24.30N', ...
'    longitude 82.96W to latitude 35.36N longitude 68.50W using a cylindrical ', ...
'    equirectangular map projection with a resolution of approximately 1.1 km/pixel.',...
'    Temperature data values are stored as 8 bit unsigned integer values (digital', ...
'    counts 0 - 255). The temperature (T) in degrees centigrade for a digital', ...
'    count of D is given by the equation: ',...
'     ', ...
'                                        T = 0.125 * D + 2',...
'   ', ... 
'    Digital count values 0-3 are reserved for graphics, a digital count of 4 ', ...
'    represent clouds.  Valid temperature values are in the range 2.625-33.875 C', ...
'    with 2.0-2.375 not used and 2.5 corresponding to clouds.', ...
'    Scaling can be turned off by setting all values of DataScale to NaN.');

Comments2 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: 1985 ', ...
'         Ending_Date: 1990 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate: 82.962 W ', ...
'              East Bounding Coordinate: 68.497 W ', ...
'              South Bounding Coordinate: 24.308 N ', ...
'              North Bounding Coordinate: 35.356 N ', ...
'    Units:  Once converted from digital counts ==> Degrees Centigrade ', ...
'    Resolution: .125 deg. C ', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address: ', ...
'               Peter Cornillon ', ...
'               Graduate School of Oceanography ', ...
'               University of Rhode Island ', ...
'               South Ferry Road ', ...
'               Narragansett, Rhode Island  02882 ', ...
'               USA ', ...
'         Electronic Mail Address:INTERNET > support@dods.gso.uri.edu ');

Comments = [Comments1 Comments2];
