%
%                            COADS CLIMATOLOGIES

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getcubic';

% FUNCTIONS -- OPTIONAL
Cat_m_File = 'levcat';
URL_m_File = 'levurl';
CatalogServer = 'http://ferret.wrc.noaa.gov/cgi-bin/nph-nc/data/levitus_climatology.nc';

% VARIABLES -- OPTIONAL
Server = 'http://ferret.wrc.noaa.gov/cgi-bin/nph-nc/data/levitus_climatology.nc';
Nlon = 360;
Nlat = 180;

% VARIABLES -- REQUIRED
LonRange = [20.000 380.000];
LatRange = [-90.000 90.000];
TimeRange = [1800 2000];
DepthRange = [0.0 5000.0];
Resolution = 55.0;

%DataName = 'Levitus (1982) Annual';
                                          % PCC Changed 12/13/98 to regularize names.
DataName = 'Water Column - Levitus (1982) Annual - PMEL';
TimeName = '';
LongitudeName = 'XAXLEVITR';
LatitudeName = 'YAXLEVITR';
DepthName = 'ZAXLEVITR';

% these names tie in to the browser as recognized common strings
% linking different datasets
SelectableVariables = str2mat('Sea_Temp', 'Salinity');
% there must be one DODSNAME for each selectable variable
DodsName = str2mat('TEMP','SALT');

% note: DataNull is applied *before* scaling
DataNull = [NaN NaN NaN NaN ...
      -10000000000.000000 ...
      -10000000000.000000];

DataScale = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; 0 1; 0 1]; 
DataRange = [NaN NaN; NaN NaN; -90 90; NaN NaN; 0 33; 28 37];

% COMMENTS
Comments1 = sprintf('%s\n', ...
    '              Levitus (1982) Climatological Atlas of the World Ocean', ...
    '    ', ...
    'Annual climatologies of salinity and temperature on 1x1 degree ',...
    'global grid at 20 levels from surface to 5000 m.  These data are ',...
    'interpolated from the original dataset, which is at 33 vertical ',...
    'levels from 0-5500m.  Use of this dataset has been by-and-large',...
    'superceded by the more recent World Ocean Atlas (Levitus et al., 1994).');
Comments2 = sprintf('%s\n', ...
    'The following has been synthesized from the reference below:', ...
    '     ',...
    'This atlas represents a synthesis of all temperature and salinity ',...
    'data available from the National Oceanographic Data Center (NODC) ',...
    'as of 1978/12/31 -- approximately 553,000 profiles, which were then',...
    'subjected to a quality-control check.  The parameters were analyzed ',...
    'in a consistent, objective manner at standard oceanographic analysis',...
    'levels on a one-degree latitude-longitude grid.',...
    '    ',...
    'The analyses and statistical information presented ',...
    'are intended primarily for use in the study of the role of the oceans in ',...
    'controlling the earth''s climate, but they can be used for other scientific',...
    'investigations also.  The objective analyses shown in this atlas have ',...
    'certain limitations owing to the nature of the data base (non-synoptic,',...
    'scattered in space) and to the characteristics of the objective analysis ',...
    'techniques and the particular grid which we used.  These limitations and ', ...
    'characteristics are discussed in the dataset text.  The analyses presented ',...
    'are viewed as another tool for studying the world ocean. Preliminary ',...
    'results have been used in a variety of ways.');

Comments3 = sprintf('%s\n', ...
    '    ', ...
    'Levitus, S., Climatological Atlas of the World Ocean, NOAA/ERL GFDL', ...
    'Professional Paper 13,  Princeton, N.J., 173 pp. (NTIS PB83-184093),', ...
    '1982.', ...
    '     ');
Comments4 = sprintf('%s\n', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date:1935 ', ...
'         Ending_Date:1978 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:0.0 ', ...
'              East Bounding Coordinate:360.0 ', ...
'              South Bounding Coordinate:-90.00 ', ...
'              North Bounding Coordinate:+90.00 ', ...
'   ', ...
'    Point_of_Contact (Science) = Sydney Levitus', ...
'         Address: E/OC5', ...
'                  National Oceanographic Data Center', ...
'                  RM 4363 Bldg SSMC3', ...
'                  1315 East-West Highway',...
'                  Silver Spring, MD 20910-3282',...
'                  USA',...
'               Telephone: (202) 626-4411', ...
'               Telephone: (202) 673-5411', ...
'         Electronic Mail Address:INTERNET > Sydney.Levitus@noaa.gov', ...
'    Point_of_Contact (Data Provision) = ', ...
'         Address: ', ...
'               Kevin O''Brien ', ...
'               NOAA/PMEL', ...
'               7600 Sand Point Way NE', ...
'               Seattle, Washington 98115-0070', ...
'               USA ', ...
'               Telephone: (206) 526-6751', ...
'         Electronic Mail Address:INTERNET > ferret@pmel.noaa.gov');

Comments = [Comments1 Comments2 Comments3 Comments4];

