%
%                            Mauna Loa CO2 Record

%N.B. Time is stored on the server in units of "HOURS since 1901-01-15 00:00:00";
%  We serve it out in units of DAYS since 1901/01/01 00:00:00;
%
% FUNCTIONS -- REQUIRED
GetFunctionName = 'getseries';

% FUNCTIONS -- OPTIONAL
URL_m_File = 'timesurl';
Cat_m_File = 'mloacat';

% VARIABLES -- OPTIONAL
CatalogServer = 'http://ferret.wrc.noaa.gov/cgi-bin/nph-nc/data/mauna_loa_co2.nc?TAX';
Server = 'http://ferret.wrc.noaa.gov/cgi-bin/nph-nc/data/mauna_loa_co2.nc';
Nlon = 1;
Nlat = 1;

% VARIABLES -- REQUIRED
LonRange = [-155.578 -155.578];
LatRange = [19.539 19.539];
TimeRange = [1958 1996];
DepthRange = [-3397 -3397];
Resolution = nan;

%DataName = 'Mauna Loa CO2';
                                          % PCC Changed 12/13/98 to regularize names.
DataName = 'CO2 - Mauna Loa - PMEL';
TimeName = 'TAX';
LongitudeName = '';
LatitudeName = '';
DepthName = '';

% these names tie in to the browser as recognized common strings
% linking different datasets
SelectableVariables = str2mat('CO2');
% there must be one DODSNAME for each selectable variable
DodsName = str2mat('CO2');

% note: DataNull is applied *before* scaling
DataNull = [NaN NaN NaN NaN ...
      -9999999790214767953607394487959552.0];
DataScale = [14 1/24; NaN NaN; NaN NaN; NaN NaN; 0 1];
DataRange = [NaN NaN; NaN NaN; -90 90; NaN NaN; nan nan];
Comments1 = sprintf('%s\n','',...
    '             Monthly time series of CO2 at Mauna Loa',...
    '    ',...
    '              (this information from the Ferret server)   ',...
    '    Grid: monthly time series from 1958-1994',...
    '    Data made available from the Carbon Dioxide Information Analysis Center',...
    '    ',...
    '    The following text is taken from the CDIAC web page:',...
    '    ',...
    '    The Mauna Loa atmospheric CO measurements constitute the longest',...
    '    continuous record of atmospheric CO2 concentrations available in the',...
    '    world. The Mauna Loa site is considered one of the most favorable',...
    '    locations for measuring undisturbed air because possible local influences',...
    '    of vegetation or human activities on atmospheric CO concentrations are',...
    '    minimal and any influences from volcanic vents may be excluded from',...
    '    the records. The methods and equipment used to obtain these',...
    '    measurements have remained essentially unchanged during the 35-year',...
    '    record.',...
    '    ',...
    '    Because of the favorable site location, continuous monitoring, and careful',...
    '    selection and scrutiny of the data, the Mauna Loa record is considered to',...
    '    be a precise record and a reliable indicator of the regional trend in the',...
    '    concentrations of atmospheric CO in the middle layers of the',...
    '    troposphere. The Mauna Loa record shows a 12.8% increase in the mean',...
    '    annual concentration, from 315.83 parts per million by volume (ppmv) of',...
    '    dry air in 1959 to 356.24 ppmv in 1992.');

Comments2 = sprintf('%s\n',...
    '    ',...
    '    IMPORTANT NOTE:  Time is given in DAYS since 1901/01/01',...
    '                        Use day2year(Time,1901) to get decimal years.',...
    '    ',...
    '    Basic facts about the MAUNA LOA OBSERVATORY',...
    '    ',...
    '    Latitude: 19.539 N                    Longitude: 155.578 W',...
    '    Elevation: 3397m (11,140ft)           Time Zone: HST (-10 GMT)',...
    '    ',...
    '                                Temperature',...
    '    ',...
    '                          Day                      Night',...
    '    Average Temperature       9C (48F)               5C (41F)',...
    '    Average Min Temperature   4C (39F)               3C (37F)',...
    '    Average Max Temperature   12C (54F)              7C (45F)',...
    '    Average Precipitation:    1.5"/month',...
    '    Average Station Pressure: 680 mbs.',...
    '    Overall Winds:            Mostly East and North-east Trades',...
    '    Local Flows:              Day-upslope; Night-downslope',...
    '    Average                   Wind Speed: 5 m/sec (11mph)',...
    '    Max Average Wind Speed:   20m/sec (45mph)',...
    '    ');
    
Comments3 = sprintf('%s\n',...
    '    ',...
    '    References:',...
    '    ',...
    '    Keeling, C.D., and T.P. Whorf. 1994.',...
    '        Atmospheric CO records from sites in the SIO air sampling network.',...
    '        In T.A. Boden, D.P. Kaiser, R.J. Sepanski, and F.W. Stoss (eds.),',...
    '        Trends ''93: A Compendium of Data on Global Change. ORNL/CDIAC-65.',...
    '        Carbon Dioxide Information Analysis Center, Oak Ridge National',...
    '        Laboratory, Oak Ridge, Tenn., U.S.A.',...
    '    ',...
    '    Point_of_Contact (Data Provision) = ', ...
    '         Address: ', ...
    '               Kevin O''Brien ', ...
    '               NOAA/PMEL', ...
    '               7600 Sand Point Way NE', ...
    '               Seattle, Washington 98115-0070', ...
    '               USA ', ...
    '               Telephone: (206) 526-6751', ...
    '         Electronic Mail Address:INTERNET > ferret@pmel.noaa.gov');

Comments = [Comments1 Comments2 Comments3];






