%                Temperature Monthly Anomalies Data at PMEL archive.

% The preceding empty line is important.
%
% $Id: ncdcanom.m,v 1.12 1999/03/06 00:26:25 dbyrne Exp $

% $Log: ncdcanom.m,v $
% Revision 1.12  1999/03/06 00:26:25  dbyrne
%
%
% fixed variable names and datarange. dbyrne 99/3/5
%
% Revision 1.14  1999/03/04 13:13:30  root
% All changes since AGU week.
%
% Revision 1.11  1999/01/24 23:48:28  jimg
% Revision 1.10  1998/11/18 19:57:02  dbyrne
%
%
% Second try.  Bug fixes to jpl pathfinder data, changed names of
% Reynolds datasets to clarify that one is a climatology and one is not.
%
% Revision 1.13  1998/11/05 16:01:53  root
% Changed LonVector and LatVector to be used if no Lon returned and tried the update function.
% DataScale and DataNull should now be optional!
%
% Revision 1.7  1998/09/14 01:32:56  dbyrne
% Elminated an inconsistency whereby the depth variable was not scaled
% and had no DataNull etc.  Added check for empty variables to plotscript.m
%
% Revision 1.12  1998/09/13 19:33:24  root
% updated DataNull &c.
%
% Revision 1.11  1998/09/13 19:21:24  root
% Eliminated an inconsistency in DataScale, DataRange, and DataNull, that
% Depth was not included!
%
% Revision 1.10  1998/09/12 15:27:47  root
% Fixed some small bugs.
%
% Revision 1.9  1998/09/12 09:36:27  root
% Fixing up TimeRanges.
%
% Revision 1.8  1998/09/11 08:16:08  dbyrne
% Longitude ranges were messed up in every archive.m file except the
% two I wrote myself.  To eliminate future confusion, 'LLon' 'Llat',
% 'Rlon' and 'Ulat' etc are being eliminated in favor of two-component
% vectors LonRange LatRange TimeRange DepthRange.
%
% Revision 1.7  1998/09/10 21:14:06  dbyrne
% Fixed some small bugs.
%
% Revision 1.6  1998/09/09 20:12:17  dbyrne
% Changing variable names to stay within 14 characters.
%
% Revision 1.5  1998/09/09 15:04:29  dbyrne
% Eliminating all global variables.
%
% Revision 1.4  1998/09/09 07:57:38  dbyrne
% replaced Data_Scale with DataScale, Data_Null with DataNull, and Data_Range
% with DataRange for consistency with other variables in the archive.m files.
%
% Revision 1.3  1998/09/09 07:40:22  dbyrne
% Replaced getrectangular with getrectg
%
% Revision 1.2  1998/09/09 07:34:22  dbyrne
% Eliminating ReturnedVariables
%
% Revision 1.1  1998/05/17 14:18:06  dbyrne
% *** empty log message ***
%
% Revision 1.3  1997/12/09 01:27:13  dbyrne
% Change misspelling of anomaly.
%
% Revision 1.2  1997/12/08 17:30:30  tom
% fixed 'nc' to correct 'nph-nc'
%
% Revision 1.1.1.1  1997/09/22 14:13:55  tom
% Imported Matlab GUI sources to CVS
%

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL
URL_m_File = 'ncdcurl';
CatalogServer = 'monthly';

% VARIABLES -- OPTIONAL
Server = 'http://ferret.wrc.noaa.gov/cgi-bin/nph-nc/data/ncdc_monthly_anomalies.nc';
Nlon = 72;
Nlat = 37;

% VARIABLES -- REQUIRED
LonRange = [0.000 360.000];
LatRange = [-90.000 90.000];
TimeRange = [1856 1994];
DepthRange = [0.0 0.0];
Resolution = 555.0;                   % avg resolution

DataName = 'Temperatures - NCDC Monthly Anomalies - PMEL';   % Name of dataset
LongitudeName = 'LONG';
LatitudeName = 'LAT';
TimeName = 'TAX_15TH';
DepthName = '';
SelectableVariables = str2mat('Temp_Diff');
DodsName = str2mat('TEMP_ANOM');
% note: DataNull is applied *before* scaling
DataNull = [nan nan nan nan -999.9990234375];
DataScale = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; 0 1];
DataRange =   [NaN NaN; NaN NaN; -90 90; NaN NaN; -15.0 15.0];

% COMMENTS
Comments1 = sprintf('%s\n', ...
'                 NCDC Monthly Temperature Anomalies (1856-1994)', ...
'                             Held at NOAA/PMEL', ...
'    ', ...
'    The data set of Monthly Temperature Anomalies was developed at The National ', ...
'    Climatic Data Center (NCDC, URL: http://www.ncdc.noaa.gov/). In June 1995, ', ...
'    the NOAA Baseline Temperature dataset (land temperatures) was merged with a ', ...
'    gridded data set of sea surface temperatures to give a truly global anomaly ',...
'    product (URL: http://www.ncdc.noaa.gov/onlineprod/landocean/monthly/form.html). ', ...
'    The ocean dataset is a compilation of data from the United Kingdom ', ...
'    Meteorological Office and the Comprehensive Oceanic and Atmospheric Data Set ', ...
'    (COADS). Monthly updates are performed by ERL using the GTS ship reports. This ', ...
'    dataset extends from 1856 to 1994. The data are gridded at 5x5deg resolution.', ...
'    ', ...
'    The complete temperature anomaly grid has an origin (indices 1,1) corresponding ', ...
'    to -90,0 and an extent (indices 32,72) given by 90,355.', ...
'    ', ...
'    References:', ...
'    ', ...
'    PMEL FERRET Documentation on NCDC Monthly Temperature Anomalies. ', ...
'    URL: http://ferret.wrc.noaa.gov/LAS/doc_htmls/ncdc_anom.cdf.html');

Comments2 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date:1856 ', ...
'         Ending_Date:1994 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:0.0 ', ...
'              East Bounding Coordinate:360.0 ', ...
'              South Bounding Coordinate:-90.00 ', ...
'              North Bounding Coordinate:+90.00 ', ...
'    Units:  Degrees Centigrade ', ...
'   ', ...
'    Point_of_Contact (Science) = ', ...
'         Electronic Mail Address:INTERNET > questions@ncdc.noaa.gov', ...
'   ', ...
'         Address: ', ...
'               C. Bruce Baker ', ...
'               NOAA/National Climate Data Center', ...
'               Global Climate Laboratory', ...
'               Federal Building', ...
'               151 Patton Avenue', ...
'               Asheville, North Carolina 28801-5001', ...
'               USA ', ...
'               Telephone: (704) 271-4430', ...
'         Electronic Mail Address:INTERNET > bbaker@ncdc.noaa.gov', ...
'   ');
Comments3 = sprintf('%s\n', ...
'         Address: ', ...
'               Henry Diaz ', ...
'               NOAA/ERL', ... 
'               Climate Diagnostics Center', ...
'               Mail Code: R/E/CD', ...
'               325 Broadway', ...
'               Boulder, Colorado 80803', ...
'               USA ', ...
'               Telephone: (303) 497-6649', ...
'               Fax: (303) 497-7013', ...
'         Electronic Mail Address:INTERNET > hfd@cdc.noaa.gov', ...
'    Point_of_Contact (Data Provision) = ', ...
'         Address: ', ...
'               Kevin O''Brien ', ...
'               NOAA/PMEL', ...
'               7600 Sand Point Way NE', ...
'               Seattle, Washington 98115-0070', ...
'               USA ', ...
'               Telephone: (206) 526-6751', ...
'         Electronic Mail Address:INTERNET > ferret@pmel.noaa.gov');

Comments = [Comments1 Comments2 Comments3];
