%
%               FILE DESCRIBING THE PATHFINDER ERODED SST CLIMATOLOGY

% The preceding empty line is important.
%
% $Id: pathero.m,v 1.9 1998/12/15 19:11:45 jimg Exp $

% $Log: pathero.m,v $
% Revision 1.9  1998/12/15 19:11:45  jimg
% Modified 'DataName' to include variable type information.
%
% Revision 1.8  1998/11/18 19:57:02  dbyrne
%
%
% Second try.  Bug fixes to jpl pathfinder data, changed names of
% Reynolds datasets to clarify that one is a climatology and one is not.
%
% Revision 1.13  1998/11/18 11:57:26  root
% Changed time range to span entire time line.
%
% Revision 1.12  1998/11/05 16:01:54  root
% Changed LonVector and LatVector to be used if no Lon returned and tried the update function.
% DataScale and DataNull should now be optional!
%
% Revision 1.5  1998/09/14 01:32:57  dbyrne
% Elminated an inconsistency whereby the depth variable was not scaled
% and had no DataNull etc.  Added check for empty variables to plotscript.m
%
% Revision 1.11  1998/09/13 19:33:25  root
% updated DataNull &c.
%
% Revision 1.10  1998/09/13 19:21:24  root
% Eliminated an inconsistency in DataScale, DataRange, and DataNull, that
% Depth was not included!
%
% Revision 1.9  1998/09/12 09:36:28  root
% Fixing up TimeRanges.
%
% Revision 1.8  1998/09/11 18:00:32  dbyrne
% undid latitude range swap!
%
% Revision 1.7  1998/09/11 08:16:09  dbyrne
% Longitude ranges were messed up in every archive.m file except the
% two I wrote myself.  To eliminate future confusion, 'LLon' 'Llat',
% 'Rlon' and 'Ulat' etc are being eliminated in favor of two-component
% vectors LonRange LatRange TimeRange DepthRange.
%
% Revision 1.6  1998/09/09 20:12:17  dbyrne
% Changing variable names to stay within 14 characters.
%
% Revision 1.5  1998/09/09 15:04:31  dbyrne
% Eliminating all global variables.
%
% Revision 1.4  1998/09/09 07:57:38  dbyrne
% replaced Data_Scale with DataScale, Data_Null with DataNull, and Data_Range
% with DataRange for consistency with other variables in the archive.m files.
%
% Revision 1.3  1998/09/09 07:40:23  dbyrne
% Replaced getrectangular with getrectg
%
% Revision 1.2  1998/09/09 07:34:23  dbyrne
% Eliminating ReturnedVariables
%
% Revision 1.1  1998/05/17 14:18:10  dbyrne
% *** empty log message ***
%
% Revision 1.1.1.1  1997/09/22 14:13:55  tom
% Imported Matlab GUI sources to CVS
%

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL
URL_m_File = 'uriclurl';
CatalogServer = 'monthly';

% VARIABLES -- OPTIONAL
Server = 'http://dods.gso.uri.edu/cgi-bin/nph-dsp/dods/sst_clima_pathero/pathero_';
Nlon = 4096;
Nlat = 2048;

% VARIABLES -- REQUIRED
LonRange = [-180.0 180.0];
LatRange = [90.0 -90.0];
TimeRange = [1800 2000];
DepthRange = [0 0];
Resolution = 9.28;

%DataName = 'Pathfinder Eroded Global SST';
                                          % PCC Changed 12/13/98 to regularize names.
DataName = 'SST - Pathfinder Eroded Global Climatology - URI';
LongitudeName = 'lon';
LatitudeName = 'lat';
TimeName = '';
DepthName = '';
SelectableVariables = str2mat('Sea_Temp');
DodsName = 'dsp_band_1';

% note: DataNull is applied *before* scaling
DataNull = [NaN NaN NaN NaN 0];
DataScale = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; -3.0 0.15];
DataRange = [NaN NaN; NaN NaN; NaN NaN; NaN NaN;  0.0 32.0];

% COMMENTS
Comments1 = sprintf('%s\n', ...
'                     URI Pathfinder Eroded Climatology', ...
'    ', ....
'    Version 1 NOAA/NASA AVHRR Oceans Pathfinder fields from 1987 through 1990 ', ... 
'    were used to generate this satellite-based SST climatology.  The input fields ', ...
'    were created at the Jet Propulsion Laboratory (JPL) by applying the annual ', ... 
'    calibration coefficients determined empirically at the University of Miami ', ... 
'    by regression against a high-quality moored and drifting buoy matchup ', ... 
'    database.  One field each day and night during the time period was created by ', ...
'    remapping the equal-area data to a global, equal-angle 4096 by 2048 pixel ', ... 
'    grid with aresolution of 9.28~km per pixel.  Nearly 3000 fields from the four ', ...
'    years were generated using the Version 1 algorithm.', ... 
'    ', ...
'    This dataset has been subjected to a two step declouding, the first ', ... 
'    declouding is done at JPL during the original Pathfinder data processing and ', ... 
'    uses channel difference and scan angle information to identify clouds.  A ', ... 
'    second declouding or "erosion"  filter is applied post-processing and flags ', ... 
'    pixels adjacent to cloudy regions, whose SST values may be slightly reduced ', ... 
'    by the presence of the cloud edge.  This erosion filter further masks as ', ... 
'    cloudy any pixel immediately adjacent to a cloudy pixel.  ', ...
'    ', ...
'    The Pathfinder plus erosion daily fields were then averaged to generate this', ... 
'    satellite-based SST climatology.  All day and night fields in each calendar', ... 
'    month were averaged to yield 12 monthly climatological mean SST fields.  ', ... 
'    Averaging of the SST fields was performed at the full 9.28 km resolution.  In ', ...
'    areas of persistent cloudiness there were a few gaps in the data.  Smoothing ', ... 
'    techniques, median filtering and linear interpolation were applied to fill in ', ...
'    gaps.', ...
'    ', ...
'    The SST temperature stored as 8 bit unsigned integer value (digital counts ', ...
'    0 - 255). The data are stored in a 2048x4096 grid with a grid lat/lon ', ...
'    resolution of .0879 degrees.  The grid origin, (indices (1,1)) correspond to ', ...
'    lat/lon of (89.956055,-179.95605). The temperature (T) in degrees centigrade ', ...
'    for given digital count (D) is given by the equation: ', ...
'    ', ...
'                                  T = -3.0 + 0.15D ', ...
'    ', ...
'    Digital count values of 0 represent land, digital count values of 1-7 are ', ...
'    reserved, and a digital count values of 8 represents ice. Valid temperature ', ... 
'    values are in the range -1.8 - 35.25 deg. C', ...
'    Scaling can be turned off by setting all values of DataScale to NaN.', ...
'    ', ...
'    References:', ... 
'    ', ...
'    K.S. Casey and P. Cornillon (1997). A Comparison of Satellite and ', ... 
'    In Situ Based Sea Surface Temperature, in preparation.');
Comments2 = sprintf('%s\n', ...
'   ', ...
'    Units:  Degrees Centigrade ', ...
'    Resolution: .15 deg. C ', ...
'    Accuracy: ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date:1987 ', ...
'         Ending_Date:1991 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:-180.0 ', ...
'              East Bounding Coordinate:180.0 ', ...
'              South Bounding Coordinate:-90.0 ', ...
'              North Bounding Coordinate:+90.0 ', ...
'    ', ...
'    Point_of_Contact = ', ...
'         Address: ', ...
'               Peter Cornillon ', ...
'               Graduate School of Oceanography ', ...
'               University of Rhode Island ', ...
'               South Ferry Road ', ...
'               Narragansett, Rhode Island  02882 ', ...
'               USA ', ...
'         Electronic Mail Address:INTERNET > support@dods.gso.uri.edu ');

Comments = [Comments1 Comments2]; 

