%               REYNOLDS SST WEEKLY MEANS

% The preceding empty line is important.
%
% $Id: reyweek.m,v 1.14 1999/03/06 00:20:53 dbyrne Exp $

% $Log: reyweek.m,v $
% Revision 1.14  1999/03/06 00:20:53  dbyrne
%
%
% changed end of TimeRange to reflect boundaries of netcdf file on server.
%
% Revision 1.17  1999/03/04 13:13:34  root
% All changes since AGU week.
%
% Revision 1.13  1998/12/15 19:10:16  jimg
% Modified 'DataName'' to include variable type information.
%
% Revision 1.12  1998/11/18 19:57:02  dbyrne
%
%
% Second try.  Bug fixes to jpl pathfinder data, changed names of
% Reynolds datasets to clarify that one is a climatology and one is not.
%
% Revision 1.16  1998/11/18 12:01:06  root
% Changed dataset names to be a little more clear.
%
% Revision 1.15  1998/11/18 11:47:32  root
% fixing documentation
%
% Revision 1.14  1998/11/18 11:44:19  root
% fixing documentation
%
% Revision 1.13  1998/11/18 11:42:56  root
% fixing documentation.
%
% Revision 1.12  1998/11/18 11:36:33  root
% *** empty log message ***
%
% Revision 1.11  1998/11/09 15:02:22  root
% Added explanation of how to convert time units.
%
% Revision 1.10  1998/11/05 16:01:56  root
% Changed LonVector and LatVector to be used if no Lon returned and tried the update function.
% DataScale and DataNull should now be optional!
%
% Revision 1.9  1998/09/14 01:32:58  dbyrne
% Elminated an inconsistency whereby the depth variable was not scaled
% and had no DataNull etc.  Added check for empty variables to plotscript.m
%
% Revision 1.9  1998/09/13 19:33:25  root
% updated DataNull &c.
%
% Revision 1.8  1998/09/13 19:21:25  root
% Eliminated an inconsistency in DataScale, DataRange, and DataNull, that
% Depth was not included!
%
% Revision 1.7  1998/09/11 18:04:11  dbyrne
% undid latitude range swap!
%
% Revision 1.6  1998/09/11 08:16:10  dbyrne
% Longitude ranges were messed up in every archive.m file except the
% two I wrote myself.  To eliminate future confusion, 'LLon' 'Llat',
% 'Rlon' and 'Ulat' etc are being eliminated in favor of two-component
% vectors LonRange LatRange TimeRange DepthRange.
%
% Revision 1.5  1998/09/09 20:12:18  dbyrne
% Changing variable names to stay within 14 characters.
%
% Revision 1.4  1998/09/09 07:57:39  dbyrne
% replaced Data_Scale with DataScale, Data_Null with DataNull, and Data_Range
% with DataRange for consistency with other variables in the archive.m files.
%
% Revision 1.3  1998/09/09 07:40:23  dbyrne
% Replaced getrectangular with getrectg
%
% Revision 1.2  1998/09/09 07:34:23  dbyrne
% Eliminating ReturnedVariables
%
% Revision 1.1  1998/05/17 14:18:12  dbyrne
% *** empty log message ***
%
% Revision 1.5  1998/01/14 01:28:25  jimg
% Added comment about the dataset in Boulder.
%
% Revision 1.4  1997/10/09 22:05:58  jimg
% Merged changes from 2.14c
%
% Revision 1.3  1997/10/04 00:33:32  jimg
% Release 2.14c fixes
%
% Revision 1.2  1997/10/01 21:34:15  tom
% Modified to use more recent dataset
%
% Revision 1.1.1.1  1997/09/22 14:13:55  tom
% Imported Matlab GUI sources to CVS
%

% Reynolds data at NOAA in Boulder.
% Note that the weekly data in Boulder are spread between two files:
% sst.wkmean.1981-1989.nc and sst.wkmean.1990-1996.nc. Also note that users
% will need DODS-2.15 or greater on the client side to read the data.

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg'; 
% FUNCTIONS -- OPTIONAL
URL_m_File = 'reywkurl'; 
CatalogServer = 'daily';

% VARIABLES -- OPTIONAL
Server = 'http://www.cdc.noaa.gov/cgi-bin/nph-nc/Datasets/reynolds_sst/';
%Server = 'http://saci.gso.uri.edu/cgi-bin/nph-nc/'; 
Nlon = 360;
Nlat = 180;
IntervalTime = 168.0; % this is one week in hours
MidTime = NaN; % what the hell is this?
% NOTE reftime puts a mark at the *end* of the interval, not the middle
% therefore RefTime = Time(1)-3.5/365;
RefTime = 1981.815068493151;

% VARIABLES -- REQUIRED
LonRange = [0.0 360.0];
LatRange = [90.0 -90.0];
TimeRange = [1981.824657534247 1996.9999999];
DepthRange = [0 0];
Resolution = 111.0;

%DataName = 'Reynolds Weekly Mean SST';   % Name for this dataset in GUI list
                                          % PCC Changed 12/13/98 to regularize names.
DataName = 'SST - Reynolds Weekly Mean - NCEP';   
LongitudeName = 'lon';
LatitudeName = 'lat';
TimeName = 'time';
DepthName = '';
SelectableVariables = str2mat('Sea_Temp');
DodsName = 'sst';

% note: DataNull is applied *before* scaling
DataNull = [nan nan nan nan nan];
DataScale = [0 1; NaN NaN; NaN NaN; NaN NaN; 0.0 0.01];
DataRange = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; -1.8, 35.09];

% COMMENTS
Comments1 = sprintf('%s\n', ...
'                               Reynolds Weekly Mean SST', ...
'   ', ...
'    This dataset is an optimally-interpolated SST analysis (Reynolds and ', ...
'    Smith 1995).  The optimum interpolation (OI) sea surface temperature', ...
'    (SST) analysis is produced weekly on a one-degree grid.  The analysis', ...
'    uses in situ and satellite SSTs plus SSTs simulated by sea-ice', ...
'    cover.  Before the analysis is computed, the satellite data is adjusted', ...
'    for biases using the method of Reynolds (1988) and Reynolds and ', ...
'    Marsico (1993).  A description of the OI analysis can be found in ', ...
'    Reynolds and Smith (1994)', ...
'    ', ....
'    The bias correction improves the large scale accuracy of the OI.', ...
'    Examples of the effect of recent corrections is given by Reynolds (1993)', ...
'    The bias correction does add a small amount of noise in time.  Most', ...
'    of the noise can be eliminated by using a 1/4 - 1/2 - 1/4 binomial', ...
'    filter in time.  The dataset author STRONGLY recommends that this', ...
'    filter be applied to the data fields before they are used.  An improved', ...
'    method of correcting the biasses is being developed', ...
'    ', ...
'    For a complete description of the data as given by the providers ', ...
'    and references for the papers cited in the description please see ', ...
'    their information file.  The dates used in the DODS file are the', ...
'    beginning of the average period. ', ...
'    ', ...
'    For more information see the Reynolds SST information web site:', ...
'    http://www.cdc.noaa.gov/cdc/reynolds_sst.info.html ', ...
'   ');

Comments2 = sprintf('%s\n', ...
'    For these data (1990 - present), the in situ data were ', ...
'    obtained from radio messages carried on the Global Telecommunications ', ...
'    System.  The satellite observations were obtained from operational ', ...
'    data produced by the National Environmental Satellite, Data and ', ...
'    Information Service (NESDIS).  For this period the weeks were defined ', ...
'    to be centered on Wednesday.  This was done to agree with the ', ...
'    definition used for ocean modeling.  ', ...
'    ', ...
'    The times are in elapsed days from 1/1/1 0:00:00. Note that January 1, 1981', ...
'    is day 723182.  Day2year(time,1) will return the time in (more intelligible) ',...
'    decimal years.', ...
'    Longitude runs from 0.5 to 359.5 (pixel grid centers)', ...
'    Latitude runs from 89.5N to 89.5S (pixel grid centers)', ...
'    Temperature data (D) are given in integer units of 0.01 degrees C. ', ...
'    ', ...
'                                  T = 0.01*D  ', ...
'    ', ...
'    SST at (110.5W,10.5S) from the beginning of 1992 should be as follows:', ...
'            91/12/29 - 92/01/04 = 24.88 ', ...
'            92/01/05 - 92/01/11 = 25.48 ', ...
'            92/01/12 - 92/01/18 = 25.40 ', ...
'            92/01/19 - 92/01/25 = 25.58 ', ...
'            92/01/26 - 92/02/01 = 25.76 ', ...
'    ', ...
'    References: ', ...
'    ', ...
'    Reynolds, R. W. (1988), A real-time global sea surface temperature ', ...
'       analysis.  J. Climate, 1, 75-86. ', ...
'   ', ...
'    Reynolds, R. W. (1993), Impact of Mount Pinatubo aerosols on ', ...
'       satellite-derived sea surface temperatures.  J. Climate 6, ', ...
'       768-774 ', ...
'   ', ...
'    Reynolds, R. and D. C. Marsico (1993), An improved real-time global ', ...
'       sea surface temperature analysis.  Journal of Climate 6, 114-119 ', ...
'   ', ...
'    Reynolds, R. and T. Smith (1994). Improved global sea surface temperature ', ...
'       analyses using optimum interpolation.  Journal of Climate 7, 929--948. ', ...
'    ', ...
'    Reynolds, R. W. and T. M. Smith (1995). A high-resolution global sea surface ',...
'       temperature climatology.  Journal of Climate 8, 1571--1583. ');

Comments3 = sprintf('%s\n', ...
'    ', ...
'    Units:  0.01 Degrees Centigrade ', ...
'    Resolution: .15 deg. C ', ...
'    Accuracy: ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date:1990 ', ...
'         Ending_Date: present', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:0.0 ', ...
'              East Bounding Coordinate:360.0 ', ...
'              South Bounding Coordinate:-90.0 ', ...
'              North Bounding Coordinate:+90.0 ', ...
'    ', ...
'    Point_of_Contact (Science) = ', ...
'         Address: ', ...
'               Richard W. Reynolds ', ...
'               Climate Modelling Branch W/NP24', ...
'               NCEP/NWS/NOAA ', ...
'               5200 Auth Road, Room 807', ...
'               Camp Springs, Maryland 20746 ', ...
'               USA ', ...
'               Telephone: (301) 763-8000 ext 7580', ...
'         Electronic Mail Address:INTERNET > rreynolds@sun1.wwb.noaa.gov', ...
'    Point_of_Contact (Data Provision) = ', ...
'         Address: ', ...
'              CDC Data Management', ...
'              Climate Diagnostics Center', ...
'              NOAA/ERL R/E/CD', ...
'              325 Broadway', ...
'              Boulder, CO  80303', ...
'         Electronic Mail Address:INTERNET > support@dods.gso.uri.edu ');

Comments = [Comments1 Comments2 Comments3]; 